@@ -4,15 +4,15 @@
 #
 
 """
-Module implementing a Qt free version of the debug client.
+Module implementing the standard debug client.
 """
 
-from AsyncIO import AsyncIO
 from DebugBase import DebugBase
-import DebugClientBase
+from DebugClientBase import DebugClientBase
+from ThreadExtension import ThreadExtension
 
 
-class DebugClient(DebugClientBase.DebugClientBase, AsyncIO, DebugBase):
+class DebugClient(DebugClientBase, DebugBase, ThreadExtension):
     """
     Class implementing the client side of the debugger.
     
@@ -23,12 +23,12 @@ class DebugClient(DebugClientBase.DebugClientBase, AsyncIO, DebugBase):
         """
         Constructor
         """
-        AsyncIO.__init__(self)
-        
-        DebugClientBase.DebugClientBase.__init__(self)
+        DebugClientBase.__init__(self)
         
         DebugBase.__init__(self, self)
         
+        ThreadExtension.__init__(self)
+        
         self.variant = 'Standard'
 
 # We are normally called by the debugger to execute directly.
@@ -38,5 +38,4 @@ if __name__ == '__main__':
     debugClient.main()
 
 #
-# eflag: FileType = Python2
-# eflag: noqa = M601, M702
+# eflag: noqa = M702
