@@ -35,11 +35,11 @@ class NamingStyleChecker(object):
     
     def __init__(self, tree, filename, options):
         """
-        Constructor (according to 'extended' pep8.py API)
+        Constructor (according to 'extended' pycodestyle.py API)
         
         @param tree AST tree of the source file
         @param filename name of the source file (string)
-        @param options options as parsed by pep8.StyleGuide
+        @param options options as parsed by pycodestyle.StyleGuide
         """
         self.__parents = collections.deque()
         self.__tree = tree
@@ -79,7 +79,7 @@ class NamingStyleChecker(object):
 
     def run(self):
         """
-        Public method run by the pep8.py checker.
+        Public method run by the pycodestyle.py checker.
         
         @return tuple giving line number, offset within line, code and
             checker function
