@@ -32,6 +32,36 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
 """ Changes
+1.2.3 (2016-05-12):
+  - Fix TypeError when processing relative imports
+
+1.2.2 (2016-05-06):
+  - Avoid traceback when exception is del-ed in except
+
+1.2.1 (2015-05-05):
+  - Fix false RedefinedWhileUnesed for submodule imports
+
+1.2.0 (2016-05-03):
+  - Warn against reusing exception names after the except block on Python 3
+  - Improve the error messages for imports
+
+1.1.0 (2016-03-01):
+  - Allow main() to accept arguments.
+  - Support @ matrix-multiplication operator
+  - Validate __future__ imports
+  - Fix doctest scope testing
+  - Warn for tuple assertions which are always true
+  - Warn for "import *" not at module level on Python 3
+  - Catch many more kinds of SyntaxErrors
+  - Check PEP 498 f-strings
+  - (and a few more sundry bugfixes)
+
+1.0.0 (2015-09-20):
+  - Python 3.5 support. async/await statements in particular.
+  - Fix test_api.py on Windows.
+  - Eliminate a false UnusedImport warning when the name has been
+    declared "global"
+
 0.9.2 (2015-06-17):
   - Fix a traceback when a global is defined in one scope, and used in another.
 
@@ -166,7 +196,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
   - Improve reporting of unbound locals
 """
 
-__version__ = '1.0.0'
+__version__ = '1.2.3+'
 
 #
 # eflag: noqa = M702
