@@ -118,19 +118,20 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             self.__addAct = self.menu.addAction(
                 self.tr("Add to repository"), self.__add)
             self.menuactions.append(self.__addAct)
-            if self.vcs.version >= (2, 0):
-                self.lfActions.append(self.menu.addAction(
-                    self.tr("Add as Large File"),
-                    lambda: self.__lfAdd("large")))
-                self.lfActions.append(self.menu.addAction(
-                    self.tr("Add as Normal File"),
-                    lambda: self.__lfAdd("normal")))
+            self.lfActions.append(self.menu.addAction(
+                self.tr("Add as Large File"),
+                lambda: self.__lfAdd("large")))
+            self.lfActions.append(self.menu.addAction(
+                self.tr("Add as Normal File"),
+                lambda: self.__lfAdd("normal")))
+            self.menu.addSeparator()
             self.__diffAct = self.menu.addAction(
                 self.tr("Show differences"), self.__diff)
             self.menuactions.append(self.__diffAct)
             self.__sbsDiffAct = self.menu.addAction(
                 self.tr("Show differences side-by-side"), self.__sbsDiff)
             self.menuactions.append(self.__sbsDiffAct)
+            self.menu.addSeparator()
             self.__revertAct = self.menu.addAction(
                 self.tr("Revert changes"), self.__revert)
             self.menuactions.append(self.__revertAct)
@@ -152,7 +153,7 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             self.statusList.customContextMenuRequested.connect(
                 self.__showContextMenu)
         
-        if not mq and self.vcs.version >= (2, 0):
+        if not mq:
             self.__lfAddActions = []
             self.__addButtonMenu = QMenu()
             self.__addButtonMenu.addAction(self.tr("Add"), self.__add)
@@ -162,8 +163,13 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             self.__lfAddActions.append(
                 self.__addButtonMenu.addAction(self.tr("Add as Normal File"),
                                                lambda: self.__lfAdd("normal")))
-            self.addButton.setMenu(self.__addButtonMenu)
             self.__addButtonMenu.aboutToShow.connect(self.__showAddMenu)
+            if self.vcs.isExtensionActive("largefiles"):
+                self.addButton.setMenu(self.__addButtonMenu)
+        
+        if not mq:
+            self.vcs.activeExtensionsChanged.connect(
+                self.__activeExtensionsChanged)
         
         self.modifiedIndicators = [
             self.tr('added'),
@@ -189,6 +195,17 @@ class HgStatusDialog(QWidget, Ui_HgStatusDialog):
             '!': self.tr('missing'),
         }
     
+    def __activeExtensionsChanged(self):
+        """
+        Private slot handling a change in the activated extensions.
+        """
+        if self.vcs.isExtensionActive("largefiles"):
+            if self.addButton.menu() is None:
+                self.addButton.setMenu(self.__addButtonMenu)
+        else:
+            if self.addButton.menu() is not None:
+                self.addButton.setMenu(None)
+    
     def show(self):
         """
         Public slot to show the dialog.
