@@ -433,7 +433,7 @@ class ProjectBrowserModel(BrowserModel):
                 bold = False
             
             if key == "SOURCES":
-                sourceLanguage = self.project.pdata["PROGLANGUAGE"][0]
+                sourceLanguage = self.project.getProjectLanguage()
             else:
                 sourceLanguage = ""
             
@@ -556,7 +556,7 @@ class ProjectBrowserModel(BrowserModel):
                 False, bold)
         else:
             if typeString == "SOURCES":
-                sourceLanguage = self.project.pdata["PROGLANGUAGE"][0]
+                sourceLanguage = self.project.getProjectLanguage()
             else:
                 sourceLanguage = ""
             itm = ProjectBrowserFileItem(
