@@ -336,7 +336,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -630,14 +630,14 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         args = []
         self.buf = ""
         
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             if self.project.getProjectType() in ["Qt4", "Qt4C"]:
                 self.rccCompiler = 'pyrcc4'
                 if Utilities.isWindowsPlatform():
                     self.rccCompiler += '.exe'
                 if PYQT_VERSION >= 0x040500:
-                    if self.project.pdata["PROGLANGUAGE"][0] in \
+                    if self.project.getProjectLanguage() in \
                             ["Python", "Python2"]:
                         args.append("-py2")
                     else:
@@ -649,7 +649,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
             elif self.project.getProjectType() in ["E6Plugin"]:
                 if PYQT_VERSION < 0x050000:
                     self.rccCompiler = 'pyrcc4'
-                    if self.project.pdata["PROGLANGUAGE"][0] in \
+                    if self.project.getProjectLanguage() in \
                             ["Python", "Python2"]:
                         args.append("-py2")
                     else:
@@ -661,14 +661,14 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
             elif self.project.getProjectType() in ["PySide", "PySideC"]:
                 self.rccCompiler = Utilities.generatePySideToolPath(
                     'pyside-rcc')
-                if self.project.pdata["PROGLANGUAGE"][0] in \
+                if self.project.getProjectLanguage() in \
                         ["Python", "Python2"]:
                     args.append("-py2")
                 else:
                     args.append("-py3")
             else:
                 return None
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             if self.project.getProjectType() == "Qt4":
                 self.rccCompiler = 'rbrcc'
                 if Utilities.isWindowsPlatform():
@@ -684,11 +684,11 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         fn = os.path.join(self.project.ppath, fn)
         
         dirname, filename = os.path.split(ofn)
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             self.compiledFile = os.path.join(
                 dirname, self.RCFilenameFormatPython.format(filename))
-        elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+        elif self.project.getProjectLanguage() == "Ruby":
             self.compiledFile = os.path.join(
                 dirname, self.RCFilenameFormatRuby.format(filename))
         
@@ -859,12 +859,12 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                 progress.setValue(i)
                 QApplication.processEvents()
                 ifn = os.path.join(self.project.ppath, fn)
-                if self.project.pdata["PROGLANGUAGE"][0] in \
+                if self.project.getProjectLanguage() in \
                    ["Python", "Python2", "Python3"]:
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(
                         dirname, self.RCFilenameFormatPython.format(filename))
-                elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
+                elif self.project.getProjectLanguage() == "Ruby":
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(
                         dirname, self.RCFilenameFormatRuby.format(filename))
