@@ -495,7 +495,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except:
+        except Exception:
             pass
         
     def __showContextMenu(self):
@@ -775,7 +775,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                      for lang in langs if lang.fileName().endswith('.ts')]
         else:
             try:
-                pattern = self.project.pdata["TRANSLATIONPATTERN"][0]\
+                pattern = self.project.pdata["TRANSLATIONPATTERN"]\
                     .replace("%language%", "*")
                 langs = [lang for lang in self.project.pdata["TRANSLATIONS"]
                          if fnmatch.fnmatch(lang, pattern)]
@@ -1026,7 +1026,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         # generate a minimal temporary projectfile suitable for pylupdate
         self.__tmpProjects = []
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             ok = self.__writeTempProjectFile(langs, [".py"])
         else:
@@ -1149,11 +1149,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     self.tr("Translation file release"),
                     self.tr("The release of the translation files (*.qm)"
                             " was successful."))
-            if self.project.pdata["TRANSLATIONSBINPATH"] and \
-                    self.project.pdata["TRANSLATIONSBINPATH"][0]:
+            if self.project.pdata["TRANSLATIONSBINPATH"]:
                 target = os.path.join(
                     self.project.ppath,
-                    self.project.pdata["TRANSLATIONSBINPATH"][0])
+                    self.project.pdata["TRANSLATIONSBINPATH"])
                 for langFile in self.project.pdata["TRANSLATIONS"][:]:
                     if langFile.endswith('.ts'):
                         qmFile = os.path.join(self.project.ppath,
@@ -1209,7 +1208,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         # generate a minimal temporary projectfile suitable for lrelease
         self.__tmpProjects = []
-        if self.project.pdata["PROGLANGUAGE"][0] in \
+        if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             ok = self.__writeTempProjectFile(langs, [".py"])
         else:
