@@ -10,8 +10,9 @@ Module implementing a previewer widget for HTML, Markdown and ReST files.
 from __future__ import unicode_literals
 
 try:  # Only for Py2
+    basestring
     import StringIO as io   # __IGNORE_EXCEPTION__
-except ImportError:
+except (ImportError, NameError):
     import io       # __IGNORE_WARNING__
 
 import os
@@ -51,15 +52,15 @@ class PreviewerHTML(QWidget):
         self.__layout.addWidget(self.titleLabel)
         
         try:
+            from PyQt5.QtWebEngineWidgets import QWebEngineView
+            self.previewView = QWebEngineView(self)
+            self.__usesWebKit = False
+        except ImportError:
             from PyQt5.QtWebKitWidgets import QWebPage, QWebView
             self.previewView = QWebView(self)
             self.previewView.page().setLinkDelegationPolicy(
                 QWebPage.DelegateAllLinks)
             self.__usesWebKit = True
-        except ImportError:
-            from PyQt5.QtWebEngineWidgets import QWebEngineView
-            self.previewView = QWebEngineView(self)
-            self.__usesWebKit = False
         
         sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
@@ -208,6 +209,8 @@ class PreviewerHTML(QWidget):
             self.previewView.page().loadFinished.connect(
                 self.__restoreScrollBarPositions)
         self.previewView.setHtml(html, baseUrl=QUrl.fromLocalFile(filePath))
+        if self.__previewedEditor:
+            self.__previewedEditor.setFocus()
     
     @pyqtSlot(str)
     def on_previewView_titleChanged(self, title):
@@ -249,7 +252,10 @@ class PreviewerHTML(QWidget):
                 "return res;"
                 "})()"
             )
-            pos = QPoint(pos["x"], pos["y"])
+            if pos is not None:
+                pos = QPoint(pos["x"], pos["y"])
+            else:
+                pos = QPoint(0, 0)
             self.__scrollBarPositions[self.__previewedPath] = pos
             self.__hScrollBarAtEnd[self.__previewedPath] = False
             self.__vScrollBarAtEnd[self.__previewedPath] = False
