@@ -666,7 +666,7 @@ class VersionControl(QObject):
         """
         if project.pudata["VCSSTATUSMONITORINTERVAL"]:
             vcsStatusMonitorInterval = project.pudata[
-                "VCSSTATUSMONITORINTERVAL"][0]
+                "VCSSTATUSMONITORINTERVAL"]
         else:
             vcsStatusMonitorInterval = Preferences.getVCS(
                 "StatusMonitorInterval")
