@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,10 +14,10 @@ This script can be used via the commandline as well.
 
 from __future__ import unicode_literals
 
-import Toolbox.PyQt4ImportHook  # __IGNORE_WARNING__ 
+import Toolbox.PyQt4ImportHook  # __IGNORE_WARNING__
 
 try:  # Only for Py2
-    import Utilities.compatibility_fixes     # __IGNORE_WARNING__
+    import Globals.compatibility_fixes     # __IGNORE_WARNING__
 except (ImportError):
     pass
 
@@ -42,7 +42,7 @@ def usage():
     """
     print("eric6_api")
     print()
-    print("Copyright (c) 2004 - 2015 Detlev Offenbach"
+    print("Copyright (c) 2004 - 2016 Detlev Offenbach"
           " <detlev@die-offenbachs.de>.")
     print()
     print("Usage:")
@@ -74,7 +74,7 @@ def usage():
     print("        This option may be repeated multiple times.")
     print("  -o filename or --output=filename")
     print("        Write the API information to the named file."
-          " A '%L' placeholder")
+          " A '%L' placeholder")        # __IGNORE_WARNING__
     print("        is replaced by the language of the API file"
           " (see --language).")
     print("  -p or --private")
@@ -101,7 +101,7 @@ def version():
         """\n"""
         """Eric6 API generator.\n"""
         """\n"""
-        """Copyright (c) 2004 - 2015 Detlev Offenbach"""
+        """Copyright (c) 2004 - 2016 Detlev Offenbach"""
         """ <detlev@die-offenbachs.de>\n"""
         """This is free software; see the LICENSE.GPL3 for copying"""
         """ conditions.\n"""
@@ -315,3 +315,6 @@ def main():
 
 if __name__ == '__main__':
     main()
+
+#
+# eflag: noqa = M801
